/*
 * UserStartTransactionActionImpl 
 *
 * 07/07/2004
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.AEF.action;

import com.ibm.retail.AEF.automation.*;
import com.ibm.retail.AEF.util.*;
import com.ibm.retail.si.util.*;
import com.ibm.retail.si.Copyright;
import com.ibm.retail.AEF.factory.*;
import com.ibm.retail.AEF.thread.*;
import com.ibm.retail.AEF.data.*;
import com.ibm.retail.AEF.session.*;
import com.ibm.retail.AEF.action.*;

import java.util.*;
import java.rmi.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 *  UserStartTransactionActionImpl overrides SAStartTransactionActionImpl
 *  to handle an additional zipcode argument on the start transaction
 *  key sequence.
 *
 */
public class UserStartTransactionActionImpl extends SAStartTransactionActionImpl
{

   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }
   private static AEFPerfTrace perfTrace  = AEFPerfTrace.getInstance();

  /**        
   * Constructor
   *
   * @param request The ActionRequest.
   * @exception AEFException
   *   AEFException error codes:
   *      <br>AEFConst.INVALID_ARGUMENT, AEFConst.INVALID_TRANSACTION_TYPE
   *
   */
   public UserStartTransactionActionImpl(ActionRequest request) throws AEFException
   {
       super(request);

       TransactionIdentifier transactionID = (TransactionIdentifier)(request.getArguments());
       zipcode = (String)(transactionID.get("zipcode"));
       if (zipcode == null || zipcode.length() == 0)
       {
          throw new AEFException(AEFConst.INVALID_ARGUMENT,
                                 -9000,           // -9000 to -9999 reserved for user error codes
                                 "UserStartTransactionActionImpl.constructor(): zipcode is a required argument.");
       }

   }



   /**        
    * Sends the key sequence which will cause the transaction to be started.
    *
    * @return int An integer value representing the result of the key sequence.
    * @exception AEFException
    */
   public int sendStartTransactionSequence() throws AEFException
   {
      if (log.isTraceEnabled())
      {
          tempAEFMessage.setMessage("+Enter SAStartTransactionActionImpl.sendStartTransactionSequence().");
          log.trace(tempAEFMessage);
      }        
      
      int retVal = -1;
      args.clear();
      args.put("SEQUENCE_ID", "startTransaction");
      args.put("%0", zipcode);
      keySequenceAction = (AEFAction)
         (actionFactory.makeAction(new ActionRequest("SimpleKeySequenceAction", args)));
      Condition[] goodConditions = 
      {
         new PropertyEqualsCondition(POSDeviceProperties.CATEGORY, POSDeviceProperties.POS_SUB_STATE, Substate.getSubstate("SELECT_PROCEDURE")),    
         new PropertyEqualsCondition(POSDeviceProperties.CATEGORY, POSDeviceProperties.POS_SUB_STATE, Substate.getSubstate("TRAINING_MODE")),       
      };
      lock = new ConditionLock();

      detector = ((DetectorAccess)(SessionContext.getSession())).getTransactionDetector();
      // Save any current transaction instance number so we are sure to only get a transaction
      // created after this key sequence is sent.
      instanceNumber = detector.getInstanceNumber();

      if (perfTrace.isEnabled(AEFPerfTrace. COARSE))
      {
         perfTrace.reportTimer(AEFPerfTrace. COARSE,
                              sessionID,
                              "startTransaction",
                              ">>>Sending start transaction key sequence to application.");
      }
      retVal = lock.performActionAndWait("wait-for-expecting-item-entry-substate",
                                         keySequenceAction,
                                         goodConditions,
                                         BadConditionsImpl.getInstance().getBadConditions(),
                                         getTimeout());


      if (retVal < 0)       
      {
          AEFErrorHandler errorHandler = new AEFErrorHandler("Send Start Transaction Sequence Error");
          retVal = errorHandler.handleError(lock,
                                            keySequenceAction,
                                            goodConditions,
                                            BadConditionsImpl.getInstance().getBadConditions(),
                                            getTimeout(),
                                            retVal);
      }

      if (perfTrace.isEnabled(AEFPerfTrace. COARSE))
      {
         perfTrace.reportTimer(AEFPerfTrace. COARSE,
                              sessionID,
                              "startTransaction",
                              "<<<Start transaction key sequence processed by application.");
      }

      if (log.isTraceEnabled())
      {
          tempAEFMessage.setMessage("-Exit SAStartTransactionActionImpl.sendStartTransactionSequence().");
          log.trace(tempAEFMessage);
      }        
      return retVal;
   }



   /* Instance Variables */
   protected String                   zipcode;
   private static Log log = LogFactory.getLog(UserStartTransactionActionImpl.class);
}
