/*
 * TillPositionListenerSupport Interface
 *
 * 07/07/2004
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * xxxx-xxx
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.AEF.event;

import java.util.*;
import java.rmi.*;

import com.ibm.retail.AEF.util.*;
import com.ibm.retail.AEF.event.*;
import com.ibm.retail.si.util.*;
import com.ibm.retail.si.util.AEFConst;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 *  ListenerSupport objects are used internally by the POSDataProvider
 *  to handle notification of events received.
 */
public class TillPositionListenerSupport extends POSAppEventListenerSupport 
{
   private static Log log = LogFactory.getLog(TillPositionListenerSupport.class);

   /**
    *  Add a listener to be notified of events handled by this support class
    *
    *  @param  listener
    *  @throws AEFException if listener is not of proper type
    *
    */
   public void addPOSAppEventListener(POSAppEventListener listener) throws AEFException
   {
      if (listener instanceof TillPositionListener)
      {
         super.addPOSAppEventListener(listener);
         if (log.isTraceEnabled())
         {
            log.trace("Added listener");
         }
      }
      else
      {
         throw (new AEFException(AEFConst.INVALID_LISTENER_TYPE, listener.getClass().getName()));
      }
   }

   /**
    *  Notify an event listener
    *
    *  @param listener
    *  @param event
    *  @throws AEFException if notification fails
    *
    */
   public void notifyListener(POSAppEventListener listener, POSAppEvent evt) throws AEFException
   {
      if (evt instanceof TillPositionEvent)
      {
         TillPositionListener l = (TillPositionListener)listener;
         try
         {
            if (log.isTraceEnabled())
            {
               log.trace("Notify listener: " + evt.toString() );
            }
            l.tillPositionChanged((TillPositionEvent)evt);
         }
         catch (Exception e)
         {
            handleListenerException(listener, e);
         }
      }
      else
      {
         // improper event type - throw an exception
         throw (new AEFException(AEFConst.EVENT_LISTENER_MISMATCH, evt.getClass().getName()));
      }
   }

   /**
    *  Returns class name of listeners that are supported
    *
    *  @return listener class name
    *
    */
   public String getListenerClassName()
   {
      return (TillPositionListener.class.getName());
   }

   /**
    *  Returns class name of POSAppEvents that are supported
    *
    *  @return event class name
    *
    */
   public String getEventClassName()
   {
      return (TillPositionEventImpl.class.getName());
   }

}
