package com.userco.retail.AEF.util;
import com.ibm.retail.AEF.action.*;
import com.ibm.retail.AEF.automation.*;
import com.ibm.retail.si.util.*;
import com.ibm.retail.si.Copyright;
import com.ibm.retail.AEF.thread.*;
import com.ibm.retail.AEF.session.*;
import com.ibm.retail.AEF.util.*;
import java.rmi.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class PickupNeededSoonErrorHelper extends SAErrorHelper
{

   // Constructor
   public PickupNeededSoonErrorHelper() throws AEFException
   {
   } 

   /** 
    * Tries to resolve the error condition if possible.
    * @param lock The ConditionLock that returned the error. 
    * @param keySequenceAction The key sequence that generated the error. 
    * @param goodConditions An array of the conditions that would indicate success after the key sequence is sent.
    * @param badConditions An array of the conditions that would indicate a failure after the key sequence is sent. 
    * @param timeout An integer used to determine how long to wait for one of the listed conditions before a timeout exception is thrown. 
    * @param satisfiedCondition The index of the condition in the badConditions array that was satisfied (needs to be adjusted as it is a negative number). 
    * @return int  Returns ErrorHelper.ERROR_HANDLED if the error was cleared or dealt with.
    * Returns ErrorHelper.ERROR_IS_FATAL if the error was not cleared or dealt with.
    */           

   public int handleError(ConditionLock lock, AEFAction keySequenceAction,                           Condition[] goodConditions, Condition[] badConditions, int timeout, int satisfiedCondition)    
   {
      int retVal = 0;
      int handlingMode = 0;
      try
      {
         handlingMode = getErrorHandlingMode();
         if (log.isInfoEnabled())
         {
            tempAEFMessage.setMessage("Pickup Needed Soon!");
            log.info(tempAEFMessage);
         }
         switch (handlingMode)
         {
         case POSAutomationProvider.HANDLE_AUTOMATIC:
            sleep(); // Added to resolve timing issues.  See sleep method for more info.
            retVal = clearError();
            break;
         case POSAutomationProvider.HANDLE_DEFAULT:
            // Unlock keyboard if need be so that the operator can interact.
            setInputDevicesLocked(false);
            retVal = waitForOperatorToClear();
            break;
         case POSAutomationProvider.HANDLE_CALLBACK:
         // Not Implemented in this release!
         default:
            throw new AEFException(AEFConst.UNSUPPORTED_ERROR_HANDLING_MODE, AEFConst.NONE, "An Error Handling Mode of " + handlingMode + " was returned which is not valid.");
         }
      }
      catch (AEFException e)
      {
         e.appendExceptions(getOuterException());
         setOuterException(e);
         retVal = ErrorHelper.ERROR_IS_FATAL;
         if (log.isWarnEnabled())
         {
            tempAEFMessage.setMessage("There was an AEF exception thrown in handleError of PickupNeededSoonErrorHelper for error " + getError().getErrorKey()+ ".");
            log.warn(tempAEFMessage, e);
         }
      }
      finally
      {
         // Reset the input devices.
         try
         {
            resetInputDevices();
         }
         catch (AEFException e)
         {
            e.appendExceptions(getOuterException());
            setOuterException(e);
            retVal = ErrorHelper.ERROR_IS_FATAL;
            if (log.isWarnEnabled())
            {
               tempAEFMessage.setMessage("There was an AEF exception thrown in handleError of PickupNeededSoonErrorHelper for error " + getError().getErrorKey()+ ".");
               log.warn(tempAEFMessage, e);
            }
         }
      }
      if (retVal < 0)
      {
         retVal = ErrorHelper.ERROR_IS_FATAL;
      }
      else
      {
         retVal = ErrorHelper.ERROR_HANDLED;
      }
      if (log.isDebugEnabled())
      {
         tempAEFMessage.setMessage("Leaving handleError for error " + getError().getErrorKey()+ ".");
         log.debug(tempAEFMessage);
         tempAEFMessage.setMessage("The return code was " + retVal + ".");
         log.debug(tempAEFMessage);
         tempAEFMessage.setMessage("The Error Handling mode used was " + handlingMode + ".");
         log.debug(tempAEFMessage);
      }
      return retVal;
   }

   // Instance Variables
   private static Log log = LogFactory.getLog(PickupNeededSoonErrorHelper.class);
}

