/*
 * AEFExample2
 *
 * 07/14/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.example2;

import com.ibm.retail.si.util.*;
import com.ibm.retail.AEF.server.*;
import com.ibm.retail.AEF.session.*;
import com.ibm.retail.AEF.automation.*;
import com.ibm.retail.AEF.factory.*;

import java.rmi.*;
import java.util.*;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class AEFExample2
{

    /*
     * The main routine
     *
     * @param args an array of strings for command line parameters
     */
    public static void main(String[] args)
    {
        String errorText = null;

        System.out.println("Starting AEFExample2...");
        try
        {
            SessionServer server = AEFBase.getInstance().getSessionServer();
            if (server != null)
            {
                //connected
                System.out.println("Obtained SessionServer");
                AEFSession session = server.getAvailableSession();
                if (session != null)
                {
                    System.out.println("Obtained session. Terminal number is " +
                                       session.getTerminalNumber());

                    System.out.println("Get an automation provider");
                    POSAutomationProvider automation = 
                    session.getPOSAutomationProvider();

                    // wait until the session is ready for commands
                    System.out.println("Wait until session is ready for commands...");
                    boolean sessionReady = session.waitUntilReady(10000);
                    int retryCount = 0;
                    while (!sessionReady)
                    {
                        retryCount++;
                        System.out.println("Retrying... #" + retryCount);
                        sessionReady = session.waitUntilReady(10000);
                        if (retryCount > 5)
                        {
                            break;
                        }
                    }
                    if (sessionReady)
                    {
                        System.out.println("Session is ready for commands.");

                        // initialize
                        System.out.println("Initialize the session to signon on state.");
                        automation.initialize(POSAutomationProvider.SIGNON);

                        // logon with default - set op/pw in userlogon.properties on 4690
                        System.out.println("Logon using default logon.");
                        Operator op = automation.logon();
                        System.out.println("Logged on as " + op.getInfo().getID());

                        // start a new transaction
                        System.out.println("Start a new transaction.");
                        SalesTransaction t1 = automation.startTransaction();
                        System.out.println("Transaction" + 
                                           t1.getTransactionInfo().getTransactionID() + "started.   ");

                        // add item 33 to the transaction

                        try
                        {
                            System.out.println("Add an item.");
                            ArrayList itemList = t1.addItem("33");
                            if ((itemList != null) && (!itemList.isEmpty()))
                            {
                                Iterator it = itemList.iterator();
                                while (it.hasNext())
                                {
                                    Item item = (Item)(it.next());
                                    System.out.println("Item added.  Description = " + 
                                                       item.getInfo().getDescription());
                                }

                                System.out.println("This is transaction " + 
                                                   t1.getTransactionInfo().getTransactionID() + ".");
                            }
                        }
                        catch (AEFException aie)
                        {
                            // Get the oldest exception in the list.

                            AEFException originalException = aie.getOriginalException();
                            
                            // Get the error codes.
                            
                            int errorCode = originalException.getErrorCode();
                            int extendedErrorCode = originalException.getErrorCodeExtended();

                            // See if we can get around this error.

                            if (errorCode == AEFConst.INVALID_ARGUMENT && extendedErrorCode == AEFConst.ITEM_PRICE_REQUIRED)
                            {
                                String tempPrice = getPrice();

                                ItemIdentifier itemID = (ItemIdentifier)(FactoryImpl.createObject(ItemIdentifier.CLASS_KEY));
                                itemID.setItemCode("33");
                                itemID.setItemCodeType(AEFConst.VELOCITY);
                                itemID.setPrice(tempPrice);

                                // Try to add the item again.

                                System.out.println("Add an item (second try).");
                                ArrayList itemList = t1.addItem(itemID);
                                if ((itemList != null) && (!itemList.isEmpty()))
                                {
                                    Iterator it = itemList.iterator();
                                    while (it.hasNext())
                                    {
                                        Item item = (Item)(it.next());
                                        System.out.println("Item added.  Description = " + 
                                                           item.getInfo().getDescription());
                                    }

                                    System.out.println("This is transaction " + 
                                                       t1.getTransactionInfo().getTransactionID() + ".");
                                }
                            }
                        }

                        // void transaction
                        System.out.println("Void transaction.");
                        t1.voidTransaction();

                        // logoff this operator
                        System.out.println("Logoff.");
                        automation.logoff();

                        // release to make the session available again
                        System.out.println("Release the session.");
                        session.release();
                        session=null;
                    }
                    else
                    {
                        errorText = "Timed out waiting for session ready";
                        System.err.println(errorText);
                        if (log.isWarnEnabled())
                        {
                            log.warn(errorText);
                        }
                    }
                }
                else
                {
                    errorText = "Unable to obtain AEFSession.  ";
                    System.err.println(errorText);
                    if (log.isWarnEnabled())
                    {
                        log.warn(errorText);
                    }
                }
            }
            else
            {
                // couldn't connect -- URL is incorrect or server is down

                errorText = "Unable to connect to AEF SessionServer.  ";
                System.err.println(errorText);
                if (log.isWarnEnabled())
                {
                    log.warn(errorText);
                }
            }
        }
        catch (AEFException ae)
        {
            errorText = "An AEF exception occurred: ";
            System.err.println(errorText + ae.getMessage()); 
            log.error(errorText, ae);
        }
        catch (RemoteException re)
        {
            errorText = "A remote exception occurred: ";
            System.err.println(errorText + re.getMessage()); 
            log.error(errorText, re);
        }
        catch (Throwable e)
        {
            errorText = "A throwable object was caught: ";
            System.err.println(errorText + e.getMessage()); 
            log.error(errorText, e);
        }
        System.out.println("AEFExample2 complete.");
        System.exit(0);
    }

    /**        
     * Gets the item's price.  
     * 
     * @return String The item's price.
     */
    public static String getPrice()
    {   
        // We will assume that there is a way to get the price from some other source.
        // The point of this example is to show how to check and handle the error.
        // Not how to get the price.
        
        return "12.00";       
    }
    
    private static Log log = LogFactory.getLog(AEFExample2.class);
}

