/*
 * AEFExample3
 *
 * 07/07/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.example1;
import com.ibm.retail.si.util.*;
import com.ibm.retail.AEF.server.*;
import com.ibm.retail.AEF.session.*;
import com.ibm.retail.AEF.automation.*;

import java.rmi.*;
import java.util.*;
import java.util.logging.*;

import com.ibm.retail.si.Copyright;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * This class demonstrates how to use a session by logging on,
 * starting a transaction, adding an item, and then suspending the
 * transaction.
 *
 **/
public class AEFExample3
{
   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }

   private static Log log = LogFactory.getLog(AEFExample3.class);
  /*
   * The main routine
   *
   * @param args an array of strings for command line parameters
   */
  public static void main(String[] args)
  {
    System.out.println("Starting AEFExample3...");
    try
    {
      SessionServer server = AEFBase.getInstance().getSessionServer();
      if (server != null)
      {
        //connected
        System.out.println("Obtained SessionServer");
        // The getSession call will block until the session is ready,
        // or until a timeout as configured via the ready.wait.timeout key
        // in config.properties.  The default is 2 minutes.
        AEFSession session = server.getSession("211");
        if (session != null)
        {
          System.out.println("Obtained session. Terminal number is " +
            session.getTerminalNumber());

          System.out.println("Get an automation provider");
          POSAutomationProvider automation = 
            session.getPOSAutomationProvider();

          // wait an additional 60 seconds (10 seconds at a time)
          // if the session is not ready for commands.
          System.out.println("Wait until session is ready for commands...");
          boolean sessionReady = session.waitUntilReady(10000);
          int retryCount = 0;
          while (!sessionReady)
          {
            retryCount++;
            System.out.println("Retrying... #" + retryCount);
            sessionReady = session.waitUntilReady(10000);
            if (retryCount > 5)
            {
              break;
            }
          }
          if (sessionReady)
          {
            System.out.println("Session is ready for commands.");

            // initialize the session so that it is ready for signon.
            System.out.println("Initialize the session to signon on state.");
            automation.initialize(POSAutomationProvider.SIGNON);

            // logon with default operator id and password as defined  in 
            // userlogon.properties on 4690
            Operator op = automation.logon();
            System.out.println("Logged on as " + op.getInfo().getID());

            // start a new transaction
            System.out.println("Start a new transaction.");
            SalesTransaction t1 = automation.startTransaction();

            // add item 1 to the transaction
            System.out.println("Add an item.");
            ArrayList itemList = t1.addItem("1");
            if ((itemList != null) && (!itemList.isEmpty()))
            {
              Iterator it = itemList.iterator();
              while (it.hasNext())
              {
                Item item = (Item)(it.next());
                System.out.println("Item added.  Description = " + 
                  item.getInfo().getDescription());
              }
            }

            System.out.println("This is transaction " + 
            t1.getTransactionInfo().getTransactionID() + ".");

            // suspend transaction
            System.out.println("Suspend transaction.");
            t1.suspend();

            // logoff this operator
            System.out.println("Logoff.");
            automation.logoff();

            // release to make the session available again
            System.out.println("Release the session.");
            session.release();
            session=null;
          }
          else
          {
            System.err.println("Timed out waiting for session ready"); 
          }

        }
        else
        {
          // could not get a session -- all sessions in use
          System.err.println("Unable to obtain AEFSession.  "); 
        }
      }
      else
      {
        // couldn't connect -- URL is incorrect or server is down
        System.err.println("Unable to connect to AEF SessionServer.  ");
      }
    }
    catch (AEFException ae)
    {
      System.err.println("An AEF exception occurred: " + ae.getMessage());
    }
    catch (RemoteException re)
    {
      System.err.println("A remote exception occurred: " + re.getMessage()); 
    }
    System.out.println("AEFExample3 complete.");
    System.exit(0);
  }
}

