/*
 * CashReceipt
 *
 * 07/07/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import java.util.*;

import java.util.logging.*;

import com.ibm.retail.AEF.data.*;
import com.ibm.retail.AEF.session.*;
import com.ibm.retail.AEF.event.*;
import com.ibm.retail.AEF.client.*;
import com.ibm.retail.si.util.*;

import com.ibm.retail.si.Copyright;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * This class is used to display the contents of the printer cash
 * receipt.
 */
public class CashReceipt extends JPanel
{

   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }

   private static Log log = LogFactory.getLog(CashReceipt.class);


   /**
    * The constructor
    *
    * @param session The session which will provide the print lines
    */
   public CashReceipt(AEFSession session) 
   {      
      super();

      this.session = session;

      setLayout(new BorderLayout());

      receiptModel = new DefaultListModel();

      receiptList = new JList(receiptModel);
      //receiptList.setVisibleRowCount(20);
      receiptPane = new JScrollPane(receiptList);

      receiptPane.setBackground(new Color(108, 161, 103));
      add(receiptPane, BorderLayout.CENTER);


      // Get the data provider.
      try
      {
         dataProvider = session.getPOSDataProvider();   
      }
      catch (Throwable th)
      {
         log.error("Error getting POSDataProvider from session.", th);
      }



      // Create a proxy for listening to state/substates property change events
      // from POSDataProvider.
      try
      {
         proxy = new CashReceiptListenerProxy(dataProvider,
                                              new ReceiptListener());
      }
      catch (Throwable th3)
      {
         log.error("Unable to attach a status property change listener.", th3);
      }

   }

   /**
    * Causes any components interested in data provider events
    * to start listening.
    *
    */
   public void startListening()
   {      
      // Can't do anything here because the proxy automatically
      // starts listening when it is created.
   }

   /**
    * Causes any components interested in data provider events
    * to stop listening.
    *
    */
   public void stopListening()
   {      
      try
      {
         proxy.removeListener();
      }
      catch (Throwable th)
      {
         log.error("CashReceipt unable to stop listening.", th);
      }
   }


  /**
   * Inner CashReceiptListener class which listens for
   * cash receipt event and updates the text field.
   *
   */
   class ReceiptListener implements CashReceiptListener
   {


      /**
       * CashReceipt Line printed
       *
       * @param event
       */
      public void linePrinted(CashReceiptEvent evt)
      {
         
         Collection printLines = evt.getPrintLines();
         Iterator it = printLines.iterator();
         while (it.hasNext())
         {
            String printLine = (String) (it.next());
            receiptModel.addElement(printLine);
            int size = receiptModel.size();
            receiptList.setSelectedIndex(size);
            receiptList.ensureIndexIsVisible(size);
         }
         try
         {
            if (evt.isPaperCut())
            {
               receiptModel.addElement("--- 8< --- PAPER CUT --- 8< ---");
            }
         }
         catch (AEFException ae)
         {
            // no paper cut ... ok
         }
      }
   }

   // Member variables
   protected AEFSession                     session;
   protected POSDataProvider                dataProvider;
   protected CashReceiptListenerProxy       proxy;
   protected JLabel                         stateLabel, substateLabel;
   protected DefaultListModel               receiptModel;
   protected JList                          receiptList;
   protected JScrollPane                    receiptPane;
}
