/*
 * CreditTenderAction
 *
 * 07/07/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.beans.*;
import java.util.*;
import java.util.prefs.*;

import com.ibm.retail.AEF.automation.*;
import com.ibm.retail.AEF.data.*;
import com.ibm.retail.AEF.session.*;

import java.util.logging.*;

import com.ibm.retail.si.Copyright;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * This class displays a dialog to query the tender arguments,
 * then uses the arguments to add the credit tender to the transaction.
 */
public class CreditTenderAction extends GUIAction
{

   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }

   private static Log log = LogFactory.getLog(CreditTenderAction.class);

   private static Preferences prefs = Preferences.userNodeForPackage(CreditTenderAction.class);
   private static String amount;      // Will default to balance due.
   private static String cardType = prefs.get("cardtype", MSRCreditIdentifier.VISA);
   private static String track1Data = prefs.get("track1data", "1111222233334444^PUBLIC/JOHN^10121011234567890123");
   private static String track2Data = prefs.get("track2data", "1111222233334444=10121011234567890123");
   private static String track3Data = prefs.get("track3data", "");
   private static JPanel form = new JPanel();
   private static JTextField amountField  = new JTextField(15);
   private static String[] cardTypeChoices = {MSRCreditIdentifier.AMEX,         
                                              MSRCreditIdentifier.CARTE_BLANCHE,
                                              MSRCreditIdentifier.DINERS_CLUB,  
                                              MSRCreditIdentifier.DISCOVER,     
                                              MSRCreditIdentifier.ENROUTE,      
                                              MSRCreditIdentifier.JCB,          
                                              MSRCreditIdentifier.MASTERCARD,   
                                              MSRCreditIdentifier.UNKNOWN,      
                                              MSRCreditIdentifier.VISA};       




   private static JComboBox cardTypeField = new JComboBox(cardTypeChoices);
   private static JTextField track1Field = new JTextField(40);
   private static JTextField track2Field = new JTextField(40);
   private static JTextField track3Field = new JTextField(40);
   static
   {
      form.setLayout(new FixedGridLayout(new Dimension(4,5)));      
      form.add(new JLabel("Amount         :"), new Rectangle(0,0,1,1));
      form.add(amountField, new Rectangle(1,0,3,1));
      form.add(new JLabel("Card Type      :"), new Rectangle(0,1,1,1));
      form.add(cardTypeField, new Rectangle(1,1,3,1));
      form.add(new JLabel("Track 1 Data  :"), new Rectangle(0,2,1,1));
      form.add(track1Field, new Rectangle(1,2,3,1));
      form.add(new JLabel("Track 2 Data  :"), new Rectangle(0,3,1,1));
      form.add(track2Field, new Rectangle(1,3,3,1));
      form.add(new JLabel("Track 3 Data  :"), new Rectangle(0,4,1,1));
      form.add(track3Field, new Rectangle(1,4,3,1));
      cardTypeField.setEditable(false);
   }




   /**
    * Called when the action is to be performed (possibly from pressing a button).
    *
    * @param evt
    *
    */
   public void actionPerformed(ActionEvent evt)
   {      
      // Display the dialog to get the OperatorIdentifier properties.
      amount = "1.00";        // Default to 1.00.
      AEFSession session = (AEFSession)(getValue("session"));
      if (session != null)
      {
         POSDataProvider dataProvider = null;
         try
         {
            dataProvider = session.getPOSDataProvider();
            String balDue = (String)dataProvider.getPropertyValue(TransactionTotalsProperties.CATEGORY,
                                                                  TransactionTotalsProperties.AMOUNT_DUE);
            if (balDue != null)
            {
               amount = balDue;
            }


         }
         catch (Throwable th)
         {
            log.error("Unable to retrieve transaction balance due.", th);
         }
      }

      // Fetch the balance due from the data provider.

      amountField.setText(amount);
      if (cardType.equals(MSRCreditIdentifier.AMEX))
      {
         cardTypeField.setSelectedIndex(0);
      }
      else if (cardType.equals(MSRCreditIdentifier.CARTE_BLANCHE))
      {
         cardTypeField.setSelectedIndex(1);
      }
      else if (cardType.equals(MSRCreditIdentifier.DINERS_CLUB))
      {
         cardTypeField.setSelectedIndex(2);
      }
      else if (cardType.equals(MSRCreditIdentifier.DISCOVER))
      {
         cardTypeField.setSelectedIndex(3);
      }
      else if (cardType.equals(MSRCreditIdentifier.ENROUTE))
      {
         cardTypeField.setSelectedIndex(4);
      }
      else if (cardType.equals(MSRCreditIdentifier.JCB))
      {
         cardTypeField.setSelectedIndex(5);
      }
      else if (cardType.equals(MSRCreditIdentifier.MASTERCARD))
      {
         cardTypeField.setSelectedIndex(6);
      }
      else if (cardType.equals(MSRCreditIdentifier.UNKNOWN))
      {
         cardTypeField.setSelectedIndex(7);
      }
      else if (cardType.equals(MSRCreditIdentifier.VISA))
      {
         cardTypeField.setSelectedIndex(8);
      }
      track1Field.setText(track1Data);
      track2Field.setText(track2Data);
      track3Field.setText(track3Data);
      int n = JOptionPane.showOptionDialog((Frame)(getValue("frame")),
                                           form,
                                           "Credit Tender Arguments",
                                           JOptionPane.OK_CANCEL_OPTION,
                                           JOptionPane.QUESTION_MESSAGE,
                                           null,
                                           null,
                                           null);
      if (n == 0)
      {
         amount        = amountField.getText();
         cardType      = (String)(cardTypeField.getSelectedItem());
         track1Data    = track1Field.getText();
         byte[] track1Bytes   = track1Data.getBytes();
         track2Data    = track2Field.getText();
         byte[] track2Bytes = track2Data.getBytes();
         track3Data    = track3Field.getText();
         byte[] track3Bytes = track3Data.getBytes();
         // For tracks 2 and 3, we have to subtract 0x30 from each
         // byte in the String to ensure proper format for the swipe.

         for (int i = 0; i < track2Bytes.length; i++)
         {
            track2Bytes[i] = ((byte)(track2Bytes[i] - 0x30));
         }
         for (int i = 0; i < track3Bytes.length; i++)
         {
            track3Bytes[i] = ((byte)(track3Bytes[i] - 0x30));
         }
         prefs.put("amount", amount);
         prefs.put("cardtype", cardType);
         prefs.put("track1data", track1Data);
         prefs.put("track2data", track2Data);
         prefs.put("track3data", track3Data);
         try
         {
            prefs.flush();
         }
         catch (Throwable th)
         {
            log.error("Unable to save credit tender form values.", th);
         }
         MSRCreditIdentifier creditID = new MSRCreditIdentifierImpl();
         if (amount != null && amount.length()>0)
         {
            creditID.setAmount(amount);
         }
         if (cardType != null && cardType.length()>0)
         {
            creditID.setCardType(cardType);
         }
         if (track1Data != null && track1Data.length()>0)
         {
            creditID.setTrack1Data(track1Bytes);
         }
         if (track2Data != null && track2Data.length()>0)
         {
            creditID.setTrack2Data(track2Bytes);
         }
         if (track3Data != null && track3Data.length()>0)
         {
            creditID.setTrack3Data(track3Bytes);
         }
         Controller controller = (Controller)(getValue("controller"));
         controller.addTender(creditID);
      }
   }




   // Member variables
}
