/*
 * GUIAction
 *
 * 07/07/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.beans.*;
import java.util.*;
import com.ibm.retail.AEF.session.*;
import java.util.logging.*;

import com.ibm.retail.si.Copyright;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * This class is an abstract base class for the action classes
 * used by SampleGUI.
 */
public abstract class GUIAction implements Action
{

   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }

   private static Log log = LogFactory.getLog(GUIAction.class);




   /**
    * Default constructor.
    *
    */
   public GUIAction()
   {      
      props = new HashMap();
      listeners = new HashSet();
      props.put("enabled", new Boolean(true));
   }


   /**
    * Add a property change listener which will be notified
    * of any property changes in the action.
    *
    * @param listener
    *
    */
   public synchronized void addPropertyChangeListener(PropertyChangeListener listener)
   {      
      listeners.add(listener);
   }



   /**
    * Returns a property value based on the specified key.
    *
    * @param key
    *
    */
   public Object getValue(String key)
   {      
      return props.get(key);
   }

   /**
    * Indicates whether the action is enabled.
    *
    * @return boolean
    *
    */
   public boolean isEnabled()
   {      
      Boolean enabled = (Boolean)(getValue("enabled"));
      if (enabled == null)
      {
         enabled = new Boolean(true);
      }
      return enabled.booleanValue();
   }


   /**
    * Sets the initial action properties.
    *
    * @param name
    * @param session
    * @param frame
    * @param controller
    * @param shortDescription
    * @param mnemonic
    * @param icon
    * @param commandKey
    *
    */
   public void initialize(String     name,
                          AEFSession session,
                          Frame      frame,
                          Controller controller,
                          String     shortDescription,
                          Integer    mnemonic,
                          Icon       icon,
                          String     commandKey)
   {      
      putValue(NAME, name);
      putValue("session", session);
      putValue("frame", frame);
      putValue("controller", controller);
      putValue(SHORT_DESCRIPTION, shortDescription);
      putValue(MNEMONIC_KEY, mnemonic);
      putValue(SMALL_ICON, icon);
      putValue(ACTION_COMMAND_KEY, commandKey);
   }


   /**
    * Sets a property value.
    *
    * @param key
    * @param value
    *
    */
   public void putValue(String key, Object value)
   {      
      Object oldValue = props.put(key, value);
      firePropertyChangeEvent(key, oldValue, value);
   }

   /**
    * Notifies the listeners of a property change.
    *
    * @param propName
    * @param oldValue
    * @param newValue
    *
    */
   public void firePropertyChangeEvent(String propName, Object oldValue, Object newValue)
   {      
      PropertyChangeEvent evt = new PropertyChangeEvent(this, propName, oldValue, newValue);
      synchronized(this)
      {
         Iterator it = listeners.iterator();
         while(it.hasNext())
         {
            PropertyChangeListener listener = (PropertyChangeListener)(it.next());
            listener.propertyChange(evt);
         }
      }
   }


   /**
    * Remove a property change listener.
    *
    * @param listener
    *
    */
   public synchronized void removePropertyChangeListener(PropertyChangeListener listener)
   {      
      listeners.remove(listener);
   }

   /**
    * Enables or disables the action.
    *
    * @param enabled true to enable.
    *
    */
   public void setEnabled(boolean enable)
   {      
      putValue("enabled", new Boolean(enable));
   }


   // Member variables
   protected HashMap          props;
   protected HashSet          listeners;
}
