/*
 * MainFrame
 *
 * 07/07/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

import java.util.logging.*;

import com.ibm.retail.AEF.session.*;

import com.ibm.retail.si.Copyright;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class MainFrame extends JFrame
{

   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }

   private static Log log = LogFactory.getLog(MainFrame.class);


   /**
    * The constructor
    *
    * @param termNum The terminal number associated with this GUI instance.
    * @param session The AEFSession associated with this GUI instance.
    * @param controller The controller for the session.
    *
    */
   public MainFrame(String termNum, AEFSession session, Controller controller)
   {      
      super("SampleGUI - " + termNum);


      this.session = session;

      JPanel contentPane = new JPanel();
      contentPane.setLayout(new FixedGridLayout(new Dimension(7,7)));
      setContentPane(contentPane);

      opDisplay = new OperatorDisplay(session);
      contentPane.add(opDisplay, new Rectangle(0,0,2,2));
                                        
      statusPanel = new StatusPanel(session);
      contentPane.add(statusPanel, new Rectangle(0,2,2,1));

      cashReceipt = new CashReceipt(session);
      contentPane.add(cashReceipt, new Rectangle(2,0,3,7));

      buttonPalette = new ButtonPalette(session, this, controller);
      contentPane.add(buttonPalette, new Rectangle(5,0,2,7));

      addWindowListener(new WindowAdapter() 
         {
            /**
             * Invoked when a window is in the process of being closed.
             * The close operation can be overridden at this point.
             */
            public void windowClosing(WindowEvent e) {
               System.exit(0);
            }

         });


      pack();

      Toolkit kit = getToolkit();
      Dimension pfSize = getSize();
      Dimension screenSize = kit.getScreenSize();
      setLocation( (screenSize.width - pfSize.width )/2,
                   (screenSize.height - pfSize.height) /2);


      setVisible(true);
      startListening();


   }

   /**
    * Causes any components interested in data provider events
    * to start listening.
    *
    */
   public void startListening()
   {      
      opDisplay.startListening();
      statusPanel.startListening();
      cashReceipt.startListening();
      buttonPalette.startListening();
   }

   /**
    * Causes any components interested in data provider events
    * to stop listening.
    *
    */
   public void stopListening()
   {      
      opDisplay.stopListening();
      statusPanel.stopListening();
      cashReceipt.stopListening();
      buttonPalette.stopListening();
   }

  /**
   * Inner ButtonListener class for closing the app
   * when the "close" button is hit.
   *
   */
   class ButtonListener implements ActionListener
   {
      /**
       * Invoked when an action occurs.
       */
      public void actionPerformed(ActionEvent e) 
      {
         stopListening();
         System.exit(0);
      }
   }

   // Member variables
   protected OperatorDisplay opDisplay;
   protected StatusPanel     statusPanel;
   protected CashReceipt     cashReceipt;
   protected ButtonPalette   buttonPalette;
   protected AEFSession      session;
}
