/*
 * OperatorDisplay
 *
 * 07/07/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

import java.util.logging.*;

import com.ibm.retail.AEF.data.*;
import com.ibm.retail.AEF.session.*;
import com.ibm.retail.AEF.event.*;
import com.ibm.retail.AEF.client.*;

import com.ibm.retail.si.Copyright;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * This class implements a GUI operator display.  It listens to the
 * POSDataProvider for updates to the operator display.
 */
public class OperatorDisplay extends JPanel
{

   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }

   private static Log log = LogFactory.getLog(OperatorDisplay.class);


   /**
    * The constructor
    *
    * @param session The session which will provide the operator display
    *                data.
    */
   public OperatorDisplay(AEFSession session)
   {      
      super();

      this.session = session;

      // Get the data provider.
      try
      {
         dataProvider = session.getPOSDataProvider();   
      }
      catch (Throwable th)
      {
         log.error("Error getting POSDataProvider from session.", th);
      }


      Border raisedBevel = BorderFactory.createRaisedBevelBorder();
      Border loweredBevel = BorderFactory.createLoweredBevelBorder();



      setBorder(BorderFactory.createCompoundBorder(
                raisedBevel, loweredBevel));
      setLayout(new FixedGridLayout(new Dimension(1,2)));
      line1 = new JTextField(20);
      line1.setBorder(BorderFactory.createEmptyBorder());
      line1.setEditable(false);
      line1.setBackground(Color.black);
      line1.setForeground(Color.green);
      line1.setFont(new Font("Monospaced",Font.PLAIN, 14));

      line2 = new JTextField(20);
      line2.setBorder(BorderFactory.createEmptyBorder());
      line2.setEditable(false);
      line2.setBackground(Color.black);
      line2.setForeground(Color.green);
      line2.setFont(new Font("Monospaced",Font.PLAIN, 14));

      add(line1, new Rectangle(0,0,1,1));
      add(line2, new Rectangle(0,1,1,1));


      // Get the initial contents from the data provider.
      if (dataProvider != null)
      {
         Object value = null;
         try
         {
            value = dataProvider.getPropertyValue(POSDeviceProperties.CATEGORY,
                                                  POSDeviceProperties.OPERATOR_PROMPT_LINE1); 
            if (value != null) line1.setText(value.toString());

            value = dataProvider.getPropertyValue(POSDeviceProperties.CATEGORY,
                                                  POSDeviceProperties.OPERATOR_PROMPT_LINE2); 
            if (value != null) line2.setText(value.toString());
         }
         catch (Throwable th2)
         {
            log.error("Unable to fetch initial operator display contents.", th2);
         }
      }

      // Create a proxy for listening for line display events from data provider.
      try
      {
         proxy = new AEFPropertyListenerProxyImpl(dataProvider,
                                                  new DisplayPropertyChangeListener());
      }
      catch (Throwable th3)
      {
         log.error("Unable to attach a line display property change listener.", th3);
      }

   }

   /**
    * Causes any components interested in data provider events
    * to start listening.
    *
    */
   public void startListening()
   {      
      try
      {
         proxy.addAEFPropertyChangeListener(POSDeviceProperties.CATEGORY,
                                            POSDeviceProperties.OPERATOR_PROMPT_LINE1);
         proxy.addAEFPropertyChangeListener(POSDeviceProperties.CATEGORY,
                                            POSDeviceProperties.OPERATOR_PROMPT_LINE2);
      }
      catch (Throwable th)
      {
         log.error("OperatorDisplay unable to start listening.", th);
      }
   }

   /**
    * Causes any components interested in data provider events
    * to stop listening.
    *
    */
   public void stopListening()
   {      
      try
      {
         proxy.removeAEFPropertyChangeListener(POSDeviceProperties.CATEGORY,
                                            POSDeviceProperties.OPERATOR_PROMPT_LINE1);
         proxy.removeAEFPropertyChangeListener(POSDeviceProperties.CATEGORY,
                                            POSDeviceProperties.OPERATOR_PROMPT_LINE2);
      }
      catch (Throwable th)
      {
         log.error("OperatorDisplay unable to stop listening.", th);
      }
   }


  /**
   * Inner AEFPropertyChangeListener class which listens for
   * operator display property changes and updates the text fields.
   *
   */
   class DisplayPropertyChangeListener implements AEFPropertyChangeListener
   {
      /**
       * An AEF property has changed.
       *
       * @param  evt contains details of the event
       * @throws RemoteException if remote access fails
       *
       */
      public void propertyChanged(AEFPropertyChangeEvent evt)
      {
         if (evt.getCategoryName().equals(POSDeviceProperties.CATEGORY))
         {
            if (evt.getPropertyName().equals(POSDeviceProperties.OPERATOR_PROMPT_LINE1))
            {
               line1.setText(evt.getNewValue().toString());
            }
            else if (evt.getPropertyName().equals(POSDeviceProperties.OPERATOR_PROMPT_LINE2))
            {
               line2.setText(evt.getNewValue().toString());
            }
         }
      }
   }

   // Member variables
   protected AEFSession                     session;
   protected POSDataProvider                dataProvider;
   protected AEFPropertyListenerProxy       proxy;
   protected JTextField                     line1, line2;
}
