/*
 * ProgressFrame
 *
 * 07/07/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

import java.util.logging.*;

import com.ibm.retail.si.Copyright;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class ProgressFrame extends JFrame
{

   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }

   private static Log log = LogFactory.getLog(ProgressFrame.class);


   /**
    * The constructor
    *
    */
   public ProgressFrame()
   {      
      super("SampleGUI");

      Border raisedBevel = BorderFactory.createRaisedBevelBorder();
      Border loweredBevel = BorderFactory.createLoweredBevelBorder();


      closeButton = new JButton("Close");
      closeButton.setActionCommand("close");
      closeButton.addActionListener(new ButtonListener());
      closeButton.setEnabled(false);

      JPanel closePanel = new JPanel();
      closePanel.setLayout(new FlowLayout());
      closePanel.add(closeButton);


      progressBar = new JProgressBar(0, 120);
      progressBar.setValue(0);
      progressBar.setStringPainted(true);
      progressBar.setBorder(BorderFactory.createCompoundBorder(
                 raisedBevel, loweredBevel));


      textArea = new JTextArea(10,40);
      textArea.setMargin(new Insets(5,5,5,5));
      textArea.setEditable(false); 
      textArea.setBorder(BorderFactory.createCompoundBorder(
           raisedBevel, loweredBevel));


      JPanel contentPane = new JPanel();
      contentPane.setLayout(new BorderLayout(5,5));
      contentPane.add(progressBar, BorderLayout.NORTH);
      contentPane.add(new JScrollPane(textArea), BorderLayout.CENTER);
      contentPane.add(closePanel, BorderLayout.SOUTH);
      contentPane.setBorder(BorderFactory.createEmptyBorder(20,20,20,20));
      setContentPane(contentPane);


      addWindowListener(new WindowAdapter() 
         {
            /**
             * Invoked when a window is in the process of being closed.
             * The close operation can be overridden at this point.
             */
            public void windowClosing(WindowEvent e) {
               System.exit(0);
            }

         });


      pack();

      Toolkit kit = getToolkit();
      Dimension pfSize = getSize();
      Dimension screenSize = kit.getScreenSize();
      setLocation( (screenSize.width - pfSize.width )/2,
                   (screenSize.height - pfSize.height) /2);


      setVisible(true);

   }

  /**
   *
   * Appends a string to the text area.
   *
   * @param text
   *
   */
   public void appendText(String text)
   {
      textArea.append(text);
   }

  /**
   *
   * Sets the progress bar to the specified value.
   *
   * @param value
   *
   */
   public void setBarValue(int value)
   {
      progressBar.setValue(value);
   }

  /**
   *
   * Sets the progress bar to the specified value.
   *
   * @param value
   *
   */
   public void setButtonEnabled(boolean flag)
   {
      closeButton.setEnabled(flag);
   }


  /**
   * Inner ButtonListener class for closing the app
   * when the "close" button is hit.
   *
   */
   class ButtonListener implements ActionListener
   {
      /**
       * Invoked when an action occurs.
       */
      public void actionPerformed(ActionEvent e) 
      {
         SampleGUI.releaseSession();
         System.exit(0);
      }
   }

   // Member variables
   private JButton               closeButton;
   private JProgressBar          progressBar;
   private JTextArea             textArea;

}
