/*
 * SampleGUI
 *
 * 07/07/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.gui;

import com.ibm.retail.AEF.server.*;
import com.ibm.retail.AEF.session.*;
import com.ibm.retail.AEF.client.*;

import java.awt.*;
import javax.swing.*;
import java.rmi.*;
import java.util.logging.*;

import com.ibm.retail.si.Copyright;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class SampleGUI 
{

   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }

   private static Log log = LogFactory.getLog(SampleGUI.class);


   /**
    * The main method
    *
    */
   public static void main(String[] args)
   {

      // Check if the user has requested help.
      if (args.length>0)
      {
         if (args[0].equalsIgnoreCase("?") ||
             args[0].equalsIgnoreCase("help") ||
             args[0].equalsIgnoreCase("/?") ||
             args[0].equalsIgnoreCase("\\?") ||
             args[0].equalsIgnoreCase("\\help") ||
             args[0].equalsIgnoreCase("/help"))
         {
            System.out.println("Usage:");
            System.out.println("   javac com.userco.retail.client.gui.SampleGUI [nnn]");
            System.out.println(" - where -");
            System.out.println("   nnn is an optional terminal number.");
            System.exit(0);
         }
      }

      progressFrame = new ProgressFrame();

      // Find a SessionServer.
      server = findSessionServer();

      if (server != null)
      {
         // Get an AEFSession
         boolean specificSession = false;
         if (args.length==0)
         {
            session = getAvailableSession();
         }
         else
         {
            session = getSpecificSession(args[0]);
            specificSession = true;
         }

         if (session != null)
         {
            Controller controller = new Controller(specificSession);
            controller.setSession(session);
            progressFrame.hide();

            try
            {
               mainFrame = new MainFrame(session.getTerminalNumber(), 
                                         session,
                                         controller);
            }
            catch (Throwable th)
            {
               log.error("Unable to retrieve terminal number.", th);
            }
         }
      }


   }


  /**
   * Retrieves an instance of SessionServer which in turn may be used
   * to fetch AEFSessions.
   *
   * @return SessionServer
   *
   */
   public static SessionServer findSessionServer()
   {
      SessionServer retVal = null;

      progressFrame.appendText("Attempting to retrieve SessionServer...");
      try
      {
         retVal = AEFBase.getInstance().getSessionServer();
         try
         {
            progressFrame.appendText("Success,  ID=" + retVal.getID() + ".\n");
         }
         catch (RemoteException re)
         {
            log.error("Failed to retrieve SessionServer ID.", re);
         }
         progressFrame.setBarValue(10);
      }
      catch (Throwable e)
      {
         progressFrame.appendText("Failed.\n");
         progressFrame.appendText("   Exception : " + e.toString() + "\n");
         progressFrame.setButtonEnabled(true);
         log.error("Failed to get SessionServer.", e);
      }
      return retVal;
   }



  /**
   * Retrieves an available session, and does not wait for it to become ready.
   * 
   *
   * @return AEFSession
   *
   */
   public static AEFSession getAvailableSession()
   {
      AEFSession retSession = null;
      SessionParameters parms = new SessionParameters();
      // A "-1" timeout value indicates that there should be no wait
      // for the session to become ready.  It should be returned immediately.
      parms.setTimeout(-1);
      progressFrame.appendText("Requesting available session...");
      try
      {
         retSession = server.getAvailableSession(parms);
         progressFrame.setBarValue(20);
         try
         {
            progressFrame.appendText("Success,  ID=" + retSession.getTerminalNumber() + ".\n");
         }
         catch (RemoteException re)
         {
            log.error("Failed to retrieve AEFSession ID.", re);
         }

         // Attach a SessionStatusListener to update the progress frame.
         try
         {
            listenerProxy = new SessionStatusListenerProxy(retSession, 
                new SessionStatusListener()
                {
                   /**
                    *  Indicates a session status event has occurred.
                    *
                    *  @param  evt contains details of SessionStatusEvent
                    *  @throws RemoteException
                    *
                    */
                    public void sessionStatusChanged(SessionStatusEvent evt)
                    {
                       progressFrame.appendText(evt.getDescription() + "\n");
                       progressFrame.setBarValue( 20 + evt.getPercentComplete());
                    }
                    /**
                    *  Indicates that the session is ready for commands.
                    *
                    *  @param  evt contains details of SessionStatusEvent
                    *  @throws RemoteException
                    *
                    */
                    public void sessionReady(SessionStatusEvent evt)
                    {
                       progressFrame.appendText(evt.getDescription() + "\n");
                       progressFrame.setBarValue( 20 + evt.getPercentComplete());
                       try
                       {
                          listenerProxy.removeListener();
                       }
                       catch (Throwable th2)
                       {
                          log.error("Unable to remove SessionStatusListener.", th2);
                       }
                    }
                    /**
                    *  Indicates that the session has ended.
                    *
                    *  @param  evt contains details of SessionStatusEvent
                    *  @throws RemoteException
                    *
                    */
                    public void sessionEnded(SessionStatusEvent evt)
                    {
                    }
                }

                                                                );


            // If the session is already ready, we can remove the 
            // session status listener, and update the progress frame.
            if (retSession.isReady())
            {
               progressFrame.appendText("Session is ready.\n");
               progressFrame.setBarValue( 120 );
               listenerProxy.removeListener();

            }
         }
         catch (Throwable th)
         {
            log.error("Unable to add SessionStausListener.", th);
         }


      }
      catch (Throwable e)
      {
         progressFrame.appendText("Failed.\n");
         progressFrame.appendText("   Exception : " + e.toString() + "\n");
         progressFrame.setButtonEnabled(true);
         log.error("Failed to get available session.", e);
      }
      return retSession;
   }

  /**
   * Retrieves a specific session by terminal number.  Does not wait for it to
   * become ready.
   * 
   *
   * @return AEFSession
   *
   */
   public static AEFSession getSpecificSession(String sessionNumber)
   {
      AEFSession retSession = null;
      SessionParameters parms = new SessionParameters();
      // A "-1" timeout value indicates that there should be no wait
      // for the session to become ready.  It should be returned immediately.
      parms.setTimeout(-1);
      progressFrame.appendText("Requesting session " + sessionNumber + "...");
      try
      {
         retSession = server.getSession(sessionNumber,parms);
         progressFrame.setBarValue(20);
         try
         {
            progressFrame.appendText("Success,  ID=" + retSession.getTerminalNumber() + ".\n");
         }
         catch (RemoteException re)
         {
            log.error("Failed to retrieve AEFSession ID.", re);
         }

         // Attach a SessionStatusListener to update the progress frame.
         try
         {
            listenerProxy = new SessionStatusListenerProxy(retSession, 
                new SessionStatusListener()
                {
                   /**
                    *  Indicates a session status event has occurred.
                    *
                    *  @param  evt contains details of SessionStatusEvent
                    *  @throws RemoteException
                    *
                    */
                    public void sessionStatusChanged(SessionStatusEvent evt)
                    {
                       progressFrame.appendText(evt.getDescription() + "\n");
                       progressFrame.setBarValue( 20 + evt.getPercentComplete());
                    }
                    /**
                    *  Indicates that the session is ready for commands.
                    *
                    *  @param  evt contains details of SessionStatusEvent
                    *  @throws RemoteException
                    *
                    */
                    public void sessionReady(SessionStatusEvent evt)
                    {
                       progressFrame.appendText(evt.getDescription() + "\n");
                       progressFrame.setBarValue( 20 + evt.getPercentComplete());
                       try
                       {
                          listenerProxy.removeListener();
                       }
                       catch (Throwable th2)
                       {
                          log.error("Unable to remove SessionStatusListener.", th2);
                       }
                    }
                    /**
                    *  Indicates that the session has ended.
                    *
                    *  @param  evt contains details of SessionStatusEvent
                    *  @throws RemoteException
                    *
                    */
                    public void sessionEnded(SessionStatusEvent evt)
                    {
                    }
                }

                                                                );


            // If the session is already ready, we can remove the 
            // session status listener, and update the progress frame.
            if (retSession.isReady())
            {
               progressFrame.appendText("Session is ready.\n");
               progressFrame.setBarValue( 120 );
               listenerProxy.removeListener();

            }
         }
         catch (Throwable th)
         {
            log.error("Unable to add SessionStausListener.", th);
         }


      }
      catch (Throwable e)
      {
         progressFrame.appendText("Failed.\n");
         progressFrame.appendText("   Exception : " + e.toString() + "\n");
         progressFrame.setButtonEnabled(true);
         log.error("Failed to get available session.", e);
      }
      return retSession;
   }

  /**
   * Release the session.
   * 
   *
   *
   */
   public static void releaseSession()
   {
      if (session != null)
      {
         try
         {
            session.release();
         }
         catch (Throwable th)
         {
            log.error("Unable to release session.", th);
         }
      }
   }


   // Member variables

   protected static SessionServer         server;
   protected static ProgressFrame         progressFrame;
   protected static AEFSession            session;
   protected static JFrame                mainFrame;
   protected static SessionStatusListenerProxy listenerProxy;
}
