/*
 * StatusPanel
 *
 * 07/07/04
 *
 * Copyright:
 * Licensed Materials - Property of IBM
 * "Restricted Materials of IBM"
 * 5724-AEF
 * (C) Copyright IBM Corp. 2004.
 *
 */
package com.userco.retail.client.gui;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;

import java.util.logging.*;

import com.ibm.retail.AEF.data.*;
import com.ibm.retail.AEF.session.*;
import com.ibm.retail.AEF.event.*;
import com.ibm.retail.AEF.client.*;

import com.ibm.retail.si.Copyright;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * This class is used to display a panel containing the current
 * application state and substate.
 */
public class StatusPanel extends JPanel
{

   static String copyright()
      { return com.ibm.retail.si.Copyright.IBM_COPYRIGHT_SHORT; }

   private static Log log = LogFactory.getLog(StatusPanel.class);


   /**
    * The constructor
    *
    * @param session The session which will provide the operator display
    *                data.
    */
   public StatusPanel(AEFSession session) 
   {      
      super();

      this.session = session;

      // Get the data provider.
      try
      {
         dataProvider = session.getPOSDataProvider();   
      }
      catch (Throwable th)
      {
         log.error("Error getting POSDataProvider from session.", th);
      }



      setBorder(BorderFactory.createLoweredBevelBorder());
      setLayout(new GridLayout(1,2));

      stateLabel = new JLabel("State : ");
      add(stateLabel);
      substateLabel = new JLabel("Substate : ");
      add(substateLabel);

      // Get the initial contents from the data provider.
      if (dataProvider != null)
      {
         Object value = null;
         try
         {
            value = dataProvider.getPropertyValue(POSDeviceProperties.CATEGORY,
                                                  POSDeviceProperties.POS_STATE); 
            if (value != null) stateLabel.setText("State : " + value.toString().trim());

            value = dataProvider.getPropertyValue(POSDeviceProperties.CATEGORY,
                                                  POSDeviceProperties.POS_SUB_STATE); 
            if (value != null) substateLabel.setText("Substate : " + value.toString().trim());
         }
         catch (Throwable th2)
         {
            log.error("Unable to fetch initial status panel contents.", th2);
         }
      }

      // Create a proxy for listening to state/substates property change events
      // from POSDataProvider.
      try
      {
         proxy = new AEFPropertyListenerProxyImpl(dataProvider,
                                                  new StatusPropertyChangeListener());
      }
      catch (Throwable th3)
      {
         log.error("Unable to attach a status property change listener.", th3);
      }

   }

   /**
    * Causes any components interested in data provider events
    * to start listening.
    *
    */
   public void startListening()
   {      
      try
      {
         proxy.addAEFPropertyChangeListener(POSDeviceProperties.CATEGORY,
                                            POSDeviceProperties.POS_STATE);
         proxy.addAEFPropertyChangeListener(POSDeviceProperties.CATEGORY,
                                            POSDeviceProperties.POS_SUB_STATE);
      }
      catch (Throwable th)
      {
         log.error("StatusPanel unable to start listening.", th);
      }
   }

   /**
    * Causes any components interested in data provider events
    * to stop listening.
    *
    */
   public void stopListening()
   {      
      try
      {
         proxy.removeAEFPropertyChangeListener(POSDeviceProperties.CATEGORY,
                                            POSDeviceProperties.POS_STATE);
         proxy.removeAEFPropertyChangeListener(POSDeviceProperties.CATEGORY,
                                            POSDeviceProperties.POS_SUB_STATE);
      }
      catch (Throwable th)
      {
         log.error("StatusPanel unable to stop listening.", th);
      }
   }


  /**
   * Inner AEFPropertyChangeListener class which listens for
   * operator display property changes and updates the text fields.
   *
   */
   class StatusPropertyChangeListener implements AEFPropertyChangeListener
   {
      /**
       * An AEF property has changed.
       *
       * @param  evt contains details of the event
       * @throws RemoteException if remote access fails
       *
       */
      public void propertyChanged(AEFPropertyChangeEvent evt)
      {
         if (evt.getCategoryName().equals(POSDeviceProperties.CATEGORY))
         {
            if (evt.getPropertyName().equals(POSDeviceProperties.POS_STATE))
            {
               stateLabel.setText("State : " + evt.getNewValue().toString().trim());
            }
            else if (evt.getPropertyName().equals(POSDeviceProperties.POS_SUB_STATE))
            {
               substateLabel.setText("Substate : " + evt.getNewValue().toString().trim());
            }
         }
      }
   }

   // Member variables
   protected AEFSession                     session;
   protected POSDataProvider                dataProvider;
   protected AEFPropertyListenerProxy       proxy;
   protected JLabel                         stateLabel, substateLabel;
}
